@@ -12,7 +12,8 @@ app_name = get_app_name()
 args = get_args()
 print('test-2')
 args.remove(app_name)
-
+print('test-3')
+print(args + "1")
 
 def main():
     if (is_name_valid(app_name)):
@@ -20,6 +21,7 @@ def main():
         # validate all arguments first!!
         if(is_args_valid(args)):
             
+            print(';;;;;;;;;;')
             # Create folder with app_name
             create_dir(app_name)
 
